@@ -60,7 +60,7 @@ class AssimpLoader::Implementation
   /// \brief the Assimp importer used to parse meshes
   public: Assimp::Importer importer;
 
-  /// \brief Convert a color from assimp implementation to Ignition common
+  /// \brief Convert a color from assimp implementation to Gazebo common
   /// \param[in] _color the assimp color to convert
   /// \return the matching math::Color
   public: math::Color ConvertColor(aiColor4D& _color) const;
@@ -116,7 +116,7 @@ class AssimpLoader::Implementation
   /// \return a pair of image pointers with the first being the metalness
   /// map and the second being the roughness map
   public: std::pair<ImagePtr, ImagePtr>
-          SplitMetallicRoughnessMap(const common::Image& _img) const;
+          SplitMetallicRoughnessMap(const Image& _img) const;
 
   /// \brief Convert an assimp mesh into a gz::common::SubMesh
   /// \param[in] _assimpMesh the assimp mesh to load
@@ -435,21 +435,15 @@ MaterialPtr AssimpLoader::Implementation::CreateMaterial(
         "MetallicRoughness"));
     // Load it into a common::Image then split it
     auto texImg = texData != nullptr ? texData :
-      std::make_shared<common::Image>(joinPaths(_path, texName));
+      std::make_shared<Image>(joinPaths(_path, texName));
     auto [metalTexture, roughTexture] =
       this->SplitMetallicRoughnessMap(*texImg);
-    if (metalTexture)
-    {
-      pbr.SetMetalnessMap(
-          this->GenerateTextureName(_fileBaseName, _scene, assimpMat,
-          "Metalness"), metalTexture);
-    }
-    if (roughTexture)
-    {
-      pbr.SetRoughnessMap(
-          this->GenerateTextureName(_fileBaseName, _scene, assimpMat,
-          "Roughness"), roughTexture);
-    }
+    pbr.SetMetalnessMap(
+        this->GenerateTextureName(_fileBaseName, _scene, assimpMat,
+        "Metalness"), metalTexture);
+    pbr.SetRoughnessMap(
+        this->GenerateTextureName(_fileBaseName, _scene, assimpMat,
+        "Roughness"), roughTexture);
   }
   else
   {
@@ -578,7 +572,7 @@ std::pair<std::string, ImagePtr> AssimpLoader::Implementation::LoadTexture(
 
 std::pair<ImagePtr, ImagePtr>
     AssimpLoader::Implementation::SplitMetallicRoughnessMap(
-    const common::Image &_img) const
+    const Image &_img) const
 {
   std::pair<ImagePtr, ImagePtr> ret;
   // Metalness in B roughness in G
@@ -593,14 +587,6 @@ std::pair<ImagePtr, ImagePtr>
       _img.ChannelData(Image::Channel::BLUE);
   std::vector<unsigned char> roughnessData8bit =
       _img.ChannelData(Image::Channel::GREEN);
-
-  if (metalnessData8bit.empty() || roughnessData8bit.empty())
-  {
-    gzerr << "Unable to extract channel data when splitting metallic "
-          << "roughness map: " << std::endl;
-    return ret;
-  }
-
   for (unsigned int y = 0; y < height; ++y)
   {
     for (unsigned int x = 0; x < width; ++x)
@@ -634,7 +620,8 @@ ImagePtr AssimpLoader::Implementation::LoadEmbeddedTexture(
 {
   if (_texture->mHeight == 0)
   {
-    Image::PixelFormatType format = Image::PixelFormatType::UNKNOWN_PIXEL_FORMAT;
+    Image::PixelFormatType format =
+        Image::PixelFormatType::UNKNOWN_PIXEL_FORMAT;
     if (_texture->CheckFormat("png"))
     {
       format = Image::PixelFormatType::COMPRESSED_PNG;
