@@ -44,12 +44,6 @@ namespace gz
       /// \brief path name of the image file
       public: std::string fullName;
 
-      /// \brief Implementation of GetData
-      /// \deprecated remove once the Data functions using raw pointers
-      /// are removed, in favor of returning vectors of bytes
-      public: void DataImpl(unsigned char **_data, unsigned int &_count,
-          FIBITMAP *_img) const;
-
       /// \brief Color type for this image
       public: FREE_IMAGE_COLOR_TYPE colorType{FIC_RGB};
 
@@ -320,23 +314,6 @@ int Image::Pitch() const
   return FreeImage_GetLine(this->dataPtr->bitmap);
 }
 
-//////////////////////////////////////////////////
-void Image::RGBData(unsigned char **_data, unsigned int &_count) const
-{
-  FIBITMAP *tmp = this->dataPtr->bitmap;
-  FIBITMAP *tmp2 = nullptr;
-  if (this->dataPtr->ShouldSwapRedBlue())
-  {
-    tmp = this->dataPtr->SwapRedBlue(this->Width(), this->Height());
-    tmp2 = tmp;
-  }
-  tmp = FreeImage_ConvertTo24Bits(tmp);
-  this->dataPtr->DataImpl(_data, _count, tmp);
-  FreeImage_Unload(tmp);
-  if (tmp2)
-    FreeImage_Unload(tmp2);
-}
-
 //////////////////////////////////////////////////
 std::vector<unsigned char> Image::RGBData() const
 {
@@ -358,23 +335,6 @@ std::vector<unsigned char> Image::RGBData() const
   return data;
 }
 
-//////////////////////////////////////////////////
-void Image::RGBAData(unsigned char **_data, unsigned int &_count) const
-{
-  FIBITMAP *tmp = this->dataPtr->bitmap;
-  FIBITMAP *tmp2 = nullptr;
-  if (this->dataPtr->ShouldSwapRedBlue())
-  {
-    tmp = this->dataPtr->SwapRedBlue(this->Width(), this->Height());
-    tmp2 = tmp;
-  }
-  tmp = FreeImage_ConvertTo32Bits(tmp);
-  this->dataPtr->DataImpl(_data, _count, tmp);
-  FreeImage_Unload(tmp);
-  if (tmp2)
-    FreeImage_Unload(tmp2);
-}
-
 //////////////////////////////////////////////////
 std::vector<unsigned char> Image::RGBAData() const
 {
@@ -396,21 +356,6 @@ std::vector<unsigned char> Image::RGBAData() const
   return data;
 }
 
-//////////////////////////////////////////////////
-void Image::Data(unsigned char **_data, unsigned int &_count) const
-{
-  if (this->dataPtr->ShouldSwapRedBlue())
-  {
-    FIBITMAP *tmp = this->dataPtr->SwapRedBlue(this->Width(), this->Height());
-    this->dataPtr->DataImpl(_data, _count, tmp);
-    FreeImage_Unload(tmp);
-  }
-  else
-  {
-    this->dataPtr->DataImpl(_data, _count, this->dataPtr->bitmap);
-  }
-}
-
 //////////////////////////////////////////////////
 std::vector<unsigned char> Image::Data() const
 {
@@ -450,57 +395,6 @@ std::vector<unsigned char> Image::Implementation::DataImpl(FIBITMAP *_img) const
   return data;
 }
 
-//////////////////////////////////////////////////
-void Image::Implementation::DataImpl(
-    unsigned char **_data, unsigned int &_count, FIBITMAP *_img) const
-{
-  int redmask = FI_RGBA_RED_MASK;
-  // int bluemask = 0x00ff0000;
-
-  int greenmask = FI_RGBA_GREEN_MASK;
-  // int greenmask = 0x0000ff00;
-
-  int bluemask = FI_RGBA_BLUE_MASK;
-  // int redmask = 0x000000ff;
-
-  int scanWidth = FreeImage_GetLine(_img);
-
-  if (*_data)
-    delete [] *_data;
-
-  _count = scanWidth * FreeImage_GetHeight(_img);
-  *_data = new unsigned char[_count];
-
-  FreeImage_ConvertToRawBits(reinterpret_cast<BYTE*>(*_data), _img,
-      scanWidth, FreeImage_GetBPP(_img), redmask, greenmask, bluemask, true);
-
-#ifdef FREEIMAGE_COLORORDER
-  // cppcheck-suppress ConfigurationNotChecked
-  if (FREEIMAGE_COLORORDER != FREEIMAGE_COLORORDER_RGB)
-  {
-#else
-#ifdef FREEIMAGE_BIGENDIAN
-  if (false)
-  {
-#else
-  {
-#endif
-#endif
-//  FIXME:  why shift by 2 pixels?
-//  this breaks heighmaps by wrapping artificially
-//    int i = 0;
-//    for (unsigned int y = 0; y < this->Height(); ++y)
-//    {
-//      for (unsigned int x = 0; x < this->Width(); ++x)
-//      {
-//        std::swap((*_data)[i], (*_data)[i+2]);
-//        unsigned int d = FreeImage_GetBPP(this->dataPtr->bitmap)/8;
-//        i += d;
-//      }
-//    }
-  }
-}
-
 //////////////////////////////////////////////////
 unsigned int Image::Width() const
 {
@@ -811,6 +705,15 @@ FIBITMAP* Image::Implementation::SwapRedBlue(const unsigned int &_width,
 //////////////////////////////////////////////////
 std::vector<unsigned char> Image::ChannelData(Channel _channel) const
 {
+  if ((this->dataPtr->imageType != FIT_BITMAP) ||
+      (this->dataPtr->colorType != FIC_RGB &&
+       this->dataPtr->colorType != FIC_RGBALPHA))
+  {
+    gzerr << "Extraction of channel data is only support for RGB[A] images"
+          << std::endl;
+    return {};
+  }
+
   FIBITMAP* channelData = nullptr;
   switch (_channel)
   {
@@ -832,8 +735,8 @@ std::vector<unsigned char> Image::ChannelData(Channel _channel) const
 
   if (!channelData)
   {
-    gzerr << "Failed to extract channel data for input channel: "
-          << static_cast<int>(_channel) << std::endl;
+    gzerr << "Invalid input channel: " << static_cast<int>(_channel)
+          << std::endl;
     return {};
   }
 
