@@ -34,10 +34,6 @@ const std::string kTestDataGazeboBmp =  // NOLINT(*)
     common::testing::TestFile("data", "gazebo_logo.bmp");
 const std::string kTestData =  // NOLINT(*)
     common::testing::TestFile("data", "red_blue_colors.png");
-const std::string kTestDataRGB16 =  // NOLINT(*)
-    common::testing::TestFile("data", "rgb_16bit.png");
-const std::string kTestDataRGBA16 =  // NOLINT(*)
-    common::testing::TestFile("data", "rgba_16bit.png");
 
 const auto kWidth = 121u;
 const auto kHeight = 81u;
@@ -330,61 +326,6 @@ TEST_F(ImageTest, SetFromCompressedData)
   ASSERT_FALSE(img.Valid());
 }
 
-TEST_F(ImageTest, DeprecatedDataFunctions)
-{
-  common::Image img;
-  ASSERT_EQ(0, img.Load(kTestData));
-  ASSERT_TRUE(img.Valid());
-
-  auto data = img.Data();
-  ASSERT_EQ(39204u, data.size());
-
-  unsigned char *dataRaw = nullptr;
-  unsigned int rawSize;
-  GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-  img.Data(&dataRaw, rawSize);
-  GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
-
-  ASSERT_EQ(data.size(), rawSize);
-
-  for (unsigned int i = 0; i < rawSize; ++i)
-  {
-    ASSERT_EQ(data[i], dataRaw[i]);
-  }
-
-  // RGBData
-  data = img.RGBData();
-  ASSERT_EQ(kSize_RGB, data.size());
-
-  GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-  img.RGBData(&dataRaw, rawSize);
-  GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
-
-  ASSERT_EQ(data.size(), rawSize);
-
-  for (unsigned int i = 0; i < rawSize; ++i)
-  {
-    ASSERT_EQ(data[i], dataRaw[i]);
-  }
-
-  // RGBAData
-  data = img.RGBAData();
-  ASSERT_EQ(39204u, data.size());
-
-  GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-  img.RGBAData(&dataRaw, rawSize);
-  GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
-
-  ASSERT_EQ(data.size(), rawSize);
-
-  for (unsigned int i = 0; i < rawSize; ++i)
-  {
-    ASSERT_EQ(data[i], dataRaw[i]);
-  }
-
-  delete[] dataRaw;
-}
-
 /*
   // save image then reload and test colors
   std::string testSaveImage =
@@ -791,7 +732,7 @@ TEST_F(ImageTest, Color16bit)
 /////////////////////////////////////////////////
 TEST_F(ImageTest, ChannelData)
 {
-  // load image, extract data from each channel and verify values
+  // load image, extra data from each channel and verify values
   common::Image img;
   ASSERT_EQ(0, img.Load(kTestData));
   ASSERT_TRUE(img.Valid());
@@ -837,88 +778,6 @@ TEST_F(ImageTest, ChannelData)
   }
 }
 
-/////////////////////////////////////////////////
-TEST_F(ImageTest, ChannelData16bit)
-{
-  {
-    // load load 16 bit RGBA image
-    // extract data from each channel and verify values
-    common::Image img;
-    ASSERT_EQ(0, img.Load(kTestDataRGBA16));
-    ASSERT_TRUE(img.Valid());
-
-    std::vector<unsigned char> red =
-        img.ChannelData(common::Image::Channel::RED);
-    std::vector<unsigned char> green =
-        img.ChannelData(common::Image::Channel::GREEN);
-    std::vector<unsigned char> blue =
-        img.ChannelData(common::Image::Channel::BLUE);
-    std::vector<unsigned char> alpha =
-        img.ChannelData(common::Image::Channel::ALPHA);
-
-    EXPECT_FALSE(red.empty());
-    ASSERT_EQ(img.Width() * img.Height(), red.size());
-    ASSERT_EQ(red.size(), green.size());
-    ASSERT_EQ(red.size(), blue.size());
-    ASSERT_EQ(red.size(), alpha.size());
-
-    for (auto i = 0u; i < img.Height(); ++i)
-    {
-      for (auto j = 0u; j < img.Width(); ++j)
-      {
-        unsigned int idx = i * img.Width() + j;
-        unsigned int r = red[idx];
-        unsigned int g = green[idx];
-        unsigned int b = blue[idx];
-        unsigned int a = alpha[idx];
-
-        EXPECT_EQ(0u, r);
-        EXPECT_EQ(0u, g);
-        EXPECT_LT(0u, b);
-        EXPECT_EQ(128u, a);
-      }
-    }
-  }
-
-  {
-    // load 16 bit RGB image (no alpha channel)
-    // extra data from each channel and verify values
-    common::Image img;
-    ASSERT_EQ(0, img.Load(kTestDataRGB16));
-    ASSERT_TRUE(img.Valid());
-
-    std::vector<unsigned char> red =
-        img.ChannelData(common::Image::Channel::RED);
-    std::vector<unsigned char> green =
-        img.ChannelData(common::Image::Channel::GREEN);
-    std::vector<unsigned char> blue =
-        img.ChannelData(common::Image::Channel::BLUE);
-    std::vector<unsigned char> alpha =
-        img.ChannelData(common::Image::Channel::ALPHA);
-
-    EXPECT_FALSE(red.empty());
-    ASSERT_EQ(img.Width() * img.Height(), red.size());
-    ASSERT_EQ(red.size(), green.size());
-    ASSERT_EQ(red.size(), blue.size());
-    ASSERT_EQ(0u, alpha.size());
-
-    for (auto i = 0u; i < img.Height(); ++i)
-    {
-      for (auto j = 0u; j < img.Width(); ++j)
-      {
-        unsigned int idx = i * img.Width() + j;
-        unsigned int r = red[idx];
-        unsigned int g = green[idx];
-        unsigned int b = blue[idx];
-
-        EXPECT_EQ(0u, r);
-        EXPECT_EQ(0u, g);
-        EXPECT_LT(0u, b);
-      }
-    }
-  }
-}
-
 using string_int2 = std::tuple<const char *, unsigned int, unsigned int>;
 
 class ImagePerformanceTest : public ImageTest,
