@@ -20,6 +20,12 @@
 namespace gz::common::testing
 {
 
+//////////////////////////////////////////////////
+CMakeTestPaths::CMakeTestPaths(const std::string &_projectSourcePath)
+  : TestPaths(_projectSourcePath)
+{
+}
+
 //////////////////////////////////////////////////
 CMakeTestPaths::~CMakeTestPaths() = default;
 
